spawn

Function spawn 

pub fn spawn<S: Server + Clone + Send + 'static>(
    jobs: Vec<CronJob>,
    server: S,
    shutdown: Receiver<()>,
)
Start the cron scheduler with an in-process protocol client.

Takes a snapshot of jobs and a Server impl (e.g. Gateway) to dispatch SendRequests through the protocol layer. Dynamic job addition is not supported through this function — use spawn_with_callback instead.